@@ -2,11 +2,10 @@
 A simple root-finding package written in Cython.
 """
 
+from ._defaults import set_default_stop_condition_args
 from ._version import __version__
-
-# Uncomment this for automatic compiling during development
-# from ._cython_extension import _has_ext
-from ._scalar_root import *
 from .bracketing import *
 from .newton import *
 from .quasi_newton import *
+from .scalar_root import *
+from .vector_root import *
